@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright 2004  Ace Jones <acejones@users.sourceforge.net>            *
+ *   Copyright 2019  Thomas Baumgart <tbaumgart@kde.org>                   *
  *                                                                         *
  *   This file is part of libalkimia.                                      *
  *                                                                         *
@@ -33,21 +34,33 @@
 #include <QApplication>
 #include <QByteArray>
 #include <QFile>
-//#include <QFileInfo>
 #include <QRegExp>
 #include <QTextStream>
 #include <QTextCodec>
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    #include <KLocalizedString>
+    #include <KIO/Scheduler>
+    #include <KIO/Job>
+    #include <QDebug>
+    #include <QTemporaryFile>
+    #define kDebug(a) qDebug()
+    #define KIcon QIcon
+    #define KUrl QUrl
+    #define prettyUrl() toDisplayString()
+#else
+    #include <KDebug>
+    #include <KGlobal>
+    #include <KLocale>
+    #include <KUrl>
+    #include <kio/netaccess.h>
+    #include <kio/scheduler.h>
+#endif
+
 #include <KConfigGroup>
-#include <KDebug>
 #include <KEncodingProber>
-#include <KGlobal>
-#include <kio/netaccess.h>
-#include <kio/scheduler.h>
-#include <KLocale>
 #include <KProcess>
 #include <KShell>
-#include <KUrl>
 
 AlkOnlineQuote::Errors::Errors()
 {
@@ -96,11 +109,13 @@ public:
     AlkOnlineQuotesProfile *m_profile;
     bool m_ownProfile;
 
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
     static int dbgArea()
     {
         static int s_area = KDebug::registerArea("Alkimia (AlkOnlineQuote)");
         return s_area;
     }
+#endif
 
     Private(AlkOnlineQuote *parent)
         : m_p(parent)
@@ -133,6 +148,9 @@ public slots:
     void slotLoadFinishedHtmlParser(bool ok);
     void slotLoadFinishedCssSelector(bool ok);
     bool slotParseQuote(const QString &_quotedata);
+
+private slots:
+    void downloadUrlDone(KJob* job);
 };
 
 bool AlkOnlineQuote::Private::initLaunch(const QString &_symbol, const QString &_id, const QString &_source)
@@ -184,7 +202,7 @@ bool AlkOnlineQuote::Private::initLaunch(const QString &_symbol, const QString &
 void AlkOnlineQuote::Private::slotLoadFinishedHtmlParser(bool ok)
 {
     if (!ok) {
-        emit m_p->error(i18n("Unable to fetch url for %1").arg(m_symbol));
+        emit m_p->error(i18n("Unable to fetch url for %1", m_symbol));
         m_errors |= Errors::URL;
         emit m_p->failed(m_id, m_symbol);
     } else {
@@ -198,7 +216,7 @@ void AlkOnlineQuote::Private::slotLoadFinishedHtmlParser(bool ok)
 void AlkOnlineQuote::Private::slotLoadFinishedCssSelector(bool ok)
 {
     if (!ok) {
-        emit m_p->error(i18n("Unable to fetch url for %1").arg(m_symbol));
+        emit m_p->error(i18n("Unable to fetch url for %1", m_symbol));
         m_errors |= Errors::URL;
         emit m_p->failed(m_id, m_symbol);
     } else {
@@ -249,6 +267,7 @@ bool AlkOnlineQuote::Private::launchWebKitCssSelector(const QString &_symbol, co
     m_eventLoop = new QEventLoop;
     m_eventLoop->exec();
     delete m_eventLoop;
+    m_eventLoop = nullptr;
     disconnect(webPage, SIGNAL(loadStarted()), this, SLOT(slotLoadStarted()));
     disconnect(webPage, SIGNAL(loadFinished(bool)), this,
                SLOT(slotLoadFinishedCssSelector(bool)));
@@ -270,6 +289,7 @@ bool AlkOnlineQuote::Private::launchWebKitHtmlParser(const QString &_symbol, con
     m_eventLoop = new QEventLoop;
     m_eventLoop->exec();
     delete m_eventLoop;
+    m_eventLoop = nullptr;
     disconnect(webPage, SIGNAL(loadStarted()), this, SLOT(slotLoadStarted()));
     disconnect(webPage, SIGNAL(loadFinished(bool)), this, SLOT(slotLoadFinishedHtmlParser(bool)));
 
@@ -312,32 +332,81 @@ bool AlkOnlineQuote::Private::launchNative(const QString &_symbol, const QString
 
 bool AlkOnlineQuote::Private::processDownloadedFile(const KUrl& url, const QString& tmpFile)
 {
-    bool result = false;
+  bool result = false;
 
-    QFile f(tmpFile);
-    if (f.open(QIODevice::ReadOnly)) {
-        // Find out the page encoding and convert it to unicode
-        QByteArray page = f.readAll();
-        KEncodingProber prober(KEncodingProber::Universal);
-        prober.feed(page);
-        QTextCodec *codec = QTextCodec::codecForName(prober.encoding());
-        if (!codec) {
-          codec = QTextCodec::codecForLocale();
-        }
-        QString quote = codec->toUnicode(page);
-        f.close();
-        emit m_p->status(i18n("URL found: %1...", url.prettyUrl()));
-        if (AlkOnlineQuotesProfileManager::instance().webPageEnabled())
-            AlkOnlineQuotesProfileManager::instance().webPage()->setContent(quote.toLocal8Bit());
-        result = slotParseQuote(quote);
-    } else {
-        emit m_p->error(i18n("Failed to open downloaded file"));
-        m_errors |= Errors::URL;
-        result = slotParseQuote(QString());
+  QFile f(tmpFile);
+  if (f.open(QIODevice::ReadOnly)) {
+    // Find out the page encoding and convert it to unicode
+    QByteArray page = f.readAll();
+    KEncodingProber prober(KEncodingProber::Universal);
+    prober.feed(page);
+    QTextCodec *codec = QTextCodec::codecForName(prober.encoding());
+    if (!codec) {
+      codec = QTextCodec::codecForLocale();
     }
+    QString quote = codec->toUnicode(page);
+    f.close();
+    emit m_p->status(i18n("URL found: %1...", url.prettyUrl()));
+    if (AlkOnlineQuotesProfileManager::instance().webPageEnabled())
+      AlkOnlineQuotesProfileManager::instance().webPage()->setContent(quote.toLocal8Bit());
+    result = slotParseQuote(quote);
+  } else {
+    emit m_p->error(i18n("Failed to open downloaded file"));
+    m_errors |= Errors::URL;
+    result = slotParseQuote(QString());
+  }
+  return result;
+}
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+bool AlkOnlineQuote::Private::downloadUrl(const QUrl& url)
+{
+    // Create a temporary filename (w/o leaving the file on the filesystem)
+    // In case the file is still present, the KIO::file_copy operation cannot
+    // be performed on some operating systems (Windows).
+    auto tmpFile = new QTemporaryFile;
+    tmpFile->open();
+    auto tmpFileName = QUrl::fromLocalFile(tmpFile->fileName());
+    delete tmpFile;
+
+    m_eventLoop = new QEventLoop;
+    KJob *job = KIO::file_copy(url, tmpFileName, -1, KIO::HideProgressInfo);
+    connect(job, SIGNAL(result(KJob*)), this, SLOT(downloadUrlDone(KJob*)));
+
+    auto result = m_eventLoop->exec(QEventLoop::ExcludeUserInputEvents);
+    delete m_eventLoop;
+    m_eventLoop = nullptr;
+
     return result;
 }
 
+void AlkOnlineQuote::Private::downloadUrlDone(KJob* job)
+{
+  QString tmpFileName = dynamic_cast<KIO::FileCopyJob*>(job)->destUrl().toLocalFile();
+  QUrl url = dynamic_cast<KIO::FileCopyJob*>(job)->srcUrl();
+
+  bool result;
+  if (!job->error()) {
+    qDebug() << "Downloaded" << tmpFileName << "from" << url;
+    result = processDownloadedFile(url, tmpFileName);
+  } else {
+    emit m_p->error(job->errorString());
+    m_errors |= Errors::URL;
+    result = slotParseQuote(QString());
+  }
+  m_eventLoop->exit(result);
+}
+
+#else
+
+// This is simply a placeholder. It is unused but needs to be present
+// to make the linker happy (since the declaration of the slot cannot
+// be made dependendant on QT_VERSION with the Qt4 moc compiler.
+void AlkOnlineQuote::Private::downloadUrlDone(KJob* job)
+{
+    Q_UNUSED(job);
+}
+
 bool AlkOnlineQuote::Private::downloadUrl(const KUrl& url)
 {
     bool result = false;
@@ -355,6 +424,7 @@ bool AlkOnlineQuote::Private::downloadUrl(const KUrl& url)
     }
     return result;
 }
+#endif
 
 #ifdef ENABLE_FINANCEQUOTE
 bool AlkOnlineQuote::Private::launchFinanceQuote(const QString &_symbol, const QString &_id,
@@ -441,17 +511,21 @@ bool AlkOnlineQuote::Private::parseDate(const QString &datestr)
             emit m_p->status(i18n("Date format found: '%1' -> '%2'", datestr, m_date.toString()));
         } catch (const AlkException &e) {
             m_errors |= Errors::DateFormat;
-            emit m_p->error(i18n("Unable to parse date '%1' using format '%2': %3").arg(datestr,
+            emit m_p->error(i18n("Unable to parse date '%1' using format '%2': %3", datestr,
                                                                                dateparse.format(),
                                                                                e.what()));
             m_date = QDate::currentDate();
-            emit m_p->status(i18n("Using current date for '%1'").arg(m_symbol));
+            emit m_p->status(i18n("Using current date for '%1'", m_symbol));
         }
     } else {
-        m_errors |= Errors::Date;
-        emit m_p->error(i18n("Unable to parse date for '%1'").arg(m_symbol));
+        if (m_source.date().isEmpty()) {
+            emit m_p->status(i18n("Parsing date is disabled for '%1'", m_symbol));
+        } else {
+            m_errors |= Errors::Date;
+            emit m_p->error(i18n("Unable to parse date for '%1'", m_symbol));
+        }
         m_date = QDate::currentDate();
-        emit m_p->status(i18n("Using current date for '%1'").arg(m_symbol));
+        emit m_p->status(i18n("Using current date for '%1'", m_symbol));
     }
     return true;
 }
@@ -587,9 +661,9 @@ bool AlkOnlineQuote::launch(const QString &_symbol, const QString &_id, const QS
         return d->launchFinanceQuote(_symbol, _id, _source);
     } else
 #endif
-        if (_source.endsWith(".css")) {
+    if (_source.endsWith(QLatin1String(".css"))) {
         return d->launchWebKitCssSelector(_symbol, _id, _source);
-    } else if (_source.endsWith(".webkit")) {
+    } else if (_source.endsWith(QLatin1String(".webkit"))) {
         return d->launchWebKitHtmlParser(_symbol, _id, _source);
     } else {
         return d->launchNative(_symbol, _id, _source);
