@@ -31,16 +31,32 @@
 #include <QtDebug>
 #include <QTreeWidget>
 
-#include <KComponentData>
-#include <KIcon>
-#include <KIconLoader>
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    #include <QIcon>
+    #include <KIconLoader>
+#include <knewstuff_version.h>
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
+    #include <kns3/downloaddialog.h>
+#else
+    #include <kns3/qtquickdialogwrapper.h>
+#endif
+    #include <kns3/uploaddialog.h>
+    #define KIcon QIcon
+#else
+    #include <KComponentData>
+    #include <KIcon>
+    #include <KIconLoader>
+    #include <knewstuff3/downloaddialog.h>
+    #include <knewstuff3/uploaddialog.h>
+#define KNEWSTUFF_VERSION 0
+#endif
+
 #include <KGuiItem>
 #include <KMessageBox>
-#include <knewstuff3/downloaddialog.h>
-#include <knewstuff3/uploaddialog.h>
+
+#include <ui_alkonlinequoteswidget.h>
 
 #if QT_VERSION < QT_VERSION_CHECK(5,0,0)
-static KComponentData alk(TRANSLATION_DOMAIN);
 #include <klocale.h>
 static KLocale _locale(TRANSLATION_DOMAIN);
 #define i18nc(context, text) ki18nc(context, text).toString(&_locale)
@@ -48,8 +64,6 @@ static KLocale _locale(TRANSLATION_DOMAIN);
 #define tr2i18n(text, context) ki18nc(context, text).toString(&_locale)
 #endif
 
-#include <ui_alkonlinequoteswidget.h>
-
 class AlkOnlineQuotesWidget::Private : public QWidget, public Ui::AlkOnlineQuotesWidget
 {
     Q_OBJECT
@@ -115,6 +129,9 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, QWid
     , m_failIcon(BarIcon("dialog-cancel"))
     , m_webPageDialog(nullptr)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
+    static KComponentData alk(TRANSLATION_DOMAIN);
+#endif
     setupUi(parent);
 
     profilesGroupBox->setVisible(showProfiles);
@@ -131,31 +148,40 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, QWid
                               KIcon("dialog-ok"),
                               i18n("Accepts the entered data and stores it"),
                               i18n("Use this to accept the modified data."));
-    m_updateButton->setGuiItem(updateButtenItem);
 
     KGuiItem deleteButtenItem(i18n("&Delete"),
                               KIcon("edit-delete"),
                               i18n("Delete the selected source entry"),
                               i18n("Use this to delete the selected online source entry"));
-    m_deleteButton->setGuiItem(deleteButtenItem);
 
     KGuiItem checkButtonItem(i18nc("Check the selected source entry", "&Check Source"),
                              KIcon("document-edit-verify"),
                              i18n("Check the selected source entry"),
                              i18n("Use this to check the selected online source entry"));
-    m_checkButton->setGuiItem(checkButtonItem);
 
     KGuiItem showButtonItem(i18nc("Show the selected source entry in a web browser", "&Show page"),
                             KIcon("applications-internet"),
                             i18n("Show the selected source entry in a web browser"),
                             i18n("Use this to show the selected online source entry"));
-    m_showButton->setGuiItem(showButtonItem);
 
     KGuiItem newButtenItem(i18nc("Create a new source entry for online quotes", "&New..."),
                            KIcon("document-new"),
                            i18n("Create a new source entry for online quotes"),
                            i18n("Use this to create a new entry for online quotes"));
+
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    KGuiItem::assign(m_updateButton, updateButtenItem);
+    KGuiItem::assign(m_deleteButton, deleteButtenItem);
+    KGuiItem::assign(m_checkButton, checkButtonItem);
+    KGuiItem::assign(m_showButton, showButtonItem);
+    KGuiItem::assign(m_newButton, newButtenItem);
+#else
+    m_updateButton->setGuiItem(updateButtenItem);
+    m_deleteButton->setGuiItem(deleteButtenItem);
+    m_checkButton->setGuiItem(checkButtonItem);
+    m_showButton->setGuiItem(showButtonItem);
     m_newButton->setGuiItem(newButtenItem);
+#endif
 
     connect(m_newProfile, SIGNAL(clicked()), this, SLOT(slotNewProfile()));
     connect(m_deleteProfile, SIGNAL(clicked()), this, SLOT(slotDeleteProfile()));
@@ -174,7 +200,11 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, QWid
     m_quoteSourceList->setRootIsDecorated(false);
     m_quoteSourceList->header()->resizeSection(1, 5);
     m_quoteSourceList->header()->setStretchLastSection(false);
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    m_quoteSourceList->header()->setSectionResizeMode(0,QHeaderView::Stretch);
+#else
     m_quoteSourceList->header()->setResizeMode(0,QHeaderView::Stretch);
+#endif
     m_quoteSourceList->setSortingEnabled(true);
 
     connect(m_quoteSourceList, SIGNAL(itemSelectionChanged()), this, SLOT(slotLoadWidgets()));
@@ -484,9 +514,14 @@ void AlkOnlineQuotesWidget::Private::setupIcons(const AlkOnlineQuote::Errors &er
         if (errors & AlkOnlineQuote::Errors::Date) {
             m_dateCheckLabel->setPixmap(m_failIcon);
         } else {
-            m_dateCheckLabel->setPixmap(m_okIcon);
-            m_dateFormatCheckLabel->setPixmap(
-                errors & AlkOnlineQuote::Errors::DateFormat ? m_failIcon : m_okIcon);
+            if (m_currentItem.date().isEmpty()) {
+                m_dateCheckLabel->setPixmap(m_emptyIcon);
+                m_dateFormatCheckLabel->setPixmap(m_emptyIcon);
+            } else {
+                m_dateCheckLabel->setPixmap(m_okIcon);
+                m_dateFormatCheckLabel->setPixmap(
+                    errors & AlkOnlineQuote::Errors::DateFormat ? m_failIcon : m_okIcon);
+            }
         }
     }
 }
@@ -557,13 +592,13 @@ void AlkOnlineQuotesWidget::Private::slotEntryRenamed(QTreeWidgetItem *item, int
     QString text = item->text(0);
     int nameCount = 0;
     for (int i = 0; i < m_quoteSourceList->topLevelItemCount(); ++i) {
-        if (m_quoteSourceList->topLevelItem(i)->text(i) == text) {
+        if (m_quoteSourceList->topLevelItem(i)->text(0) == text) {
             ++nameCount;
         }
     }
 
     // Make sure we get a non-empty and unique name
-    if (text.length() > 0 && nameCount == 1) {
+    if (text.length() > 0 && nameCount == 0) {
         m_currentItem.rename(text);
     } else {
         item->setText(0, m_currentItem.name());
@@ -578,10 +613,17 @@ void AlkOnlineQuotesWidget::Private::slotInstallEntries()
 {
     QString configFile = m_profile->hotNewStuffConfigFile();
 
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
     QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(configFile, this);
     dialog->exec();
     delete dialog;
     loadQuotesList();
+#else
+    if (!KNS3::QtQuickDialogWrapper(configFile).exec().isEmpty()) {
+        // Only load the list if entries are changed
+        loadQuotesList();
+    }
+#endif
 }
 
 void AlkOnlineQuotesWidget::Private::slotUploadEntry()
