@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright 2019  Ralf Habacker ralf.habacker@freenet.de                *
+ *   Copyright 2019  Thomas Baumgart <tbaumgart@kde.org>                   *
  *                                                                         *
  *   This file is part of libalkimia.                                      *
  *                                                                         *
@@ -21,22 +22,10 @@
 #include "alkonlinequotesprofile.h"
 #include "alkonlinequotesprofilemanager.h"
 
-#include <KComponentData>
-
 #include <QApplication>
 #include <QDialog>
 #include <QGridLayout>
 
-class Dialog : public QDialog {
-public:
-    Dialog()
-    {
-        QGridLayout *layout = new QGridLayout;
-        layout->addWidget(new AlkOnlineQuotesWidget);
-        setLayout(layout);
-    }
-};
-
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
@@ -44,7 +33,10 @@ int main(int argc, char *argv[])
     AlkOnlineQuotesProfile profile("no-config-file", AlkOnlineQuotesProfile::Type::None);
     AlkOnlineQuotesProfileManager::instance().addProfile(&profile);
 
-    Dialog dialog;
+    QDialog dialog;
+    QGridLayout *layout = new QGridLayout;
+    layout->addWidget(new AlkOnlineQuotesWidget);
+    dialog.setLayout(layout);
     dialog.show();
     app.exec();
 }
